/*
 *   Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 *   Licensed under the Apache License, Version 2.0 (the "License").
 *   You may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 */
'use strict';
Object.defineProperty(exports, "__esModule", { value: true });
exports.CommandSchemaValidator = void 0;
var Ajv_1 = require("./util/Ajv");
var StaticAplTemplateValidator_1 = require("./StaticAplTemplateValidator");
var ValidationErrorFilter_1 = require("./util/ValidationErrorFilter");
var IValidationInfo_1 = require("./IValidationInfo");
var AnimationItemCommandJSONSchema = require("./assets/commands/AnimationItemCommand");
var AutoPageCommandJSONSchema = require("./assets/commands/AutoPageCommand");
var ClearFocusCommandJSONSchema = require("./assets/commands/ClearFocusCommand");
var ControlMediaCommandJSONSchema = require("./assets/commands/ControlMediaCommand");
var IdleCommandJSONSchema = require("./assets/commands/IdleCommand");
var OpenURLCommandJSONSchema = require("./assets/commands/OpenURLCommand");
var ParallelCommandJSONSchema = require("./assets/commands/ParallelCommand");
var PlayMediaCommandJSONSchema = require("./assets/commands/PlayMediaCommand");
var ScrollCommandJSONSchema = require("./assets/commands/ScrollCommand");
var ScrollToComponentCommandJSONSchema = require("./assets/commands/ScrollToComponentCommand");
var ScrollToIndexCommandJSONSchema = require("./assets/commands/ScrollToIndexCommand");
var SendEventCommandJSONSchema = require("./assets/commands/SendEventCommand");
var SequentialCommandJSONSchema = require("./assets/commands/SequentialCommand");
var SetFocusCommandJSONSchema = require("./assets/commands/SetFocusCommand");
var SetPageCommandJSONSchema = require("./assets/commands/SetPageCommand");
var SetStateCommandJSONSchema = require("./assets/commands/SetStateCommand");
var SetValueCommandJSONSchema = require("./assets/commands/SetValueCommand");
var SpeakItemCommandJSONSchema = require("./assets/commands/SpeakItemCommand");
var SpeakListCommandJSONSchema = require("./assets/commands/SpeakListCommand");
var FinishCommandJSONSchema = require("./assets/commands/FinishCommand");
var SelectCommandJSONSchema = require("./assets/commands/SelectCommand");
var ReinflateCommandJSONSchema = require("./assets/commands/ReinflateCommand");
var InsertItemCommandJSONSchema = require("./assets/commands/InsertItemCommand");
var RemoveItemCommandJSONSchema = require("./assets/commands/RemoveItemCommand");
var LogCommandJSONSchema = require("./assets/commands/LogCommand");
/**
 * Entrance to validate commands.
 * @export
 * @class Validator
 */
var CommandSchemaValidator = /** @class */ (function () {
    /**
     * Creates an instance of CommandSchemaValidator.
     * @memberof CommandSchemaValidator
     */
    function CommandSchemaValidator() {
    }
    /**
     * Singleton method.
     * @static
     * @returns {CommandSchemaValidator}
     * @memberof CommandSchemaValidator
     */
    CommandSchemaValidator.getInstance = function () {
        if (!this.instance) {
            this.instance = new CommandSchemaValidator();
        }
        return this.instance;
    };
    /**
     * Validate command.
     * @param {object} jsonObject
     * @param {string} commandType
     * @returns {IValidationInfo[]}
     * @memberof CommandSchemaValidator
     */
    CommandSchemaValidator.prototype.validateCommand = function (jsonObject, commandType) {
        var validateFunction = Ajv_1.default.getSchema(commandType);
        var results = [];
        if (!validateFunction) {
            var commandJsonSchema = CommandSchemaValidator.COMMAND_TYPE_TO_JSON_SCHEMA
                .get(commandType);
            if (!commandJsonSchema) {
                results.push({
                    errorMessage: 'Failed to find JSON schema for command: ' + commandType,
                    path: '/',
                    level: IValidationInfo_1.NotificationLevel.WARN
                });
                return results;
            }
            validateFunction = Ajv_1.default.addSchema(commandJsonSchema, commandType).getSchema(commandType);
        }
        var succeed = validateFunction(jsonObject);
        if (succeed) {
            return [];
        }
        ValidationErrorFilter_1.ValidationErrorFilter.filterErrors(validateFunction.errors, ValidationErrorFilter_1.ValidationErrorFilter.singleDataPathFilterNoRootPath).filter(ValidationErrorFilter_1.ValidationErrorFilter.userDefinedPropertyErrorFilter)
            .forEach(function (eachError) {
            results.push(StaticAplTemplateValidator_1.StaticAplTemplateValidator.asValidationWarnInfo(eachError));
        });
        return results;
    };
    /**
     * All supported command type to json schema mapping.
     * @static
     * @memberof CommandSchemaValidator
     */
    CommandSchemaValidator.COMMAND_TYPE_TO_JSON_SCHEMA = new Map([
        ['AnimateItem', AnimationItemCommandJSONSchema.JSON_SCHEMA],
        ['AutoPage', AutoPageCommandJSONSchema.JSON_SCHEMA],
        ['ClearFocus', ClearFocusCommandJSONSchema.JSON_SCHEMA],
        ['ControlMedia', ControlMediaCommandJSONSchema.JSON_SCHEMA],
        ['Idle', IdleCommandJSONSchema.JSON_SCHEMA],
        ['OpenURL', OpenURLCommandJSONSchema.JSON_SCHEMA],
        ['Parallel', ParallelCommandJSONSchema.JSON_SCHEMA],
        ['PlayMedia', PlayMediaCommandJSONSchema.JSON_SCHEMA],
        ['Scroll', ScrollCommandJSONSchema.JSON_SCHEMA],
        ['ScrollToComponent', ScrollToComponentCommandJSONSchema.JSON_SCHEMA],
        ['ScrollToIndex', ScrollToIndexCommandJSONSchema.JSON_SCHEMA],
        ['SendEvent', SendEventCommandJSONSchema.JSON_SCHEMA],
        ['Sequential', SequentialCommandJSONSchema.JSON_SCHEMA],
        ['SetFocus', SetFocusCommandJSONSchema.JSON_SCHEMA],
        ['SetPage', SetPageCommandJSONSchema.JSON_SCHEMA],
        ['SetState', SetStateCommandJSONSchema.JSON_SCHEMA],
        ['SetValue', SetValueCommandJSONSchema.JSON_SCHEMA],
        ['SpeakItem', SpeakItemCommandJSONSchema.JSON_SCHEMA],
        ['SpeakList', SpeakListCommandJSONSchema.JSON_SCHEMA],
        ['Finish', FinishCommandJSONSchema.JSON_SCHEMA],
        ['Select', SelectCommandJSONSchema.JSON_SCHEMA],
        ['Reinflate', ReinflateCommandJSONSchema.JSON_SCHEMA],
        ['InsertItem', InsertItemCommandJSONSchema.JSON_SCHEMA],
        ['RemoveItem', RemoveItemCommandJSONSchema.JSON_SCHEMA],
        ['Log', LogCommandJSONSchema.JSON_SCHEMA]
    ]);
    return CommandSchemaValidator;
}());
exports.CommandSchemaValidator = CommandSchemaValidator;
//# sourceMappingURL=CommandSchemaValidator.js.map