/*
 *   Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 *   Licensed under the Apache License, Version 2.0 (the "License").
 *   You may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 */
'use strict';
Object.defineProperty(exports, "__esModule", { value: true });
exports.GraphicSchemaValidator = void 0;
var Ajv_1 = require("./util/Ajv");
var StaticAplTemplateValidator_1 = require("./StaticAplTemplateValidator");
var ValidationErrorFilter_1 = require("./util/ValidationErrorFilter");
var IValidationInfo_1 = require("./IValidationInfo");
var AVGGroupItemJSONSchema = require("./assets/graphics/AVGGroupItem");
var AVGPathItemJSONSchema = require("./assets/graphics/AVGPathItem");
var AVGTextItemJSONSchema = require("./assets/graphics/AVGTextItem");
var AVGJSONSchema = require("./assets/graphics/AVG");
/**
 * Entrance to validate graphics.
 * @export
 * @class Validator
 */
var GraphicSchemaValidator = /** @class */ (function () {
    /**
     * Creates an instance of GraphicSchemaValidator.
     * @memberof GraphicSchemaValidator
     */
    function GraphicSchemaValidator() {
    }
    /**
     * Singleton method.
     * @static
     * @returns {GraphicSchemaValidator}
     * @memberof GraphicSchemaValidator
     */
    GraphicSchemaValidator.getInstance = function () {
        if (!this.instance) {
            this.instance = new GraphicSchemaValidator();
        }
        return this.instance;
    };
    /**
     * Validate graphic.
     * @param {object} jsonObject
     * @param {string} graphicType
     * @returns {IValidationInfo[]}
     * @memberof GraphicSchemaValidator
     */
    GraphicSchemaValidator.prototype.validateGraphic = function (jsonObject, graphicType) {
        var schemaId = 'avg_' + graphicType;
        var results = [];
        var validateFunction = Ajv_1.default.getSchema(schemaId);
        if (!validateFunction) {
            var graphicJsonSchema = GraphicSchemaValidator.GRAPHIC_TYPE_TO_JSON_SCHEMA
                .get(graphicType);
            if (!graphicJsonSchema) {
                results.push({
                    errorMessage: 'Failed to find JSON schema for graphic: ' + graphicType,
                    path: '/',
                    level: IValidationInfo_1.NotificationLevel.WARN
                });
                return results;
            }
            validateFunction = Ajv_1.default.addSchema(graphicJsonSchema, schemaId).getSchema(schemaId);
        }
        var succeed = validateFunction(jsonObject);
        if (succeed) {
            return [];
        }
        ValidationErrorFilter_1.ValidationErrorFilter.filterErrors(validateFunction.errors, ValidationErrorFilter_1.ValidationErrorFilter.singleDataPathFilterNoRootPath).filter(ValidationErrorFilter_1.ValidationErrorFilter.userDefinedPropertyErrorFilter)
            .forEach(function (eachError) {
            results.push(StaticAplTemplateValidator_1.StaticAplTemplateValidator.asValidationWarnInfo(eachError));
        });
        return results;
    };
    /**
     * Get graphic schema
     * @param {string} graphicType {'root', 'group', 'text', 'path'}
     * @returns {IJsonSchema}
     * @memberof GraphicSchemaValidator
     */
    GraphicSchemaValidator.prototype.getGraphicSchema = function (graphicType) {
        var graphicJsonSchema = GraphicSchemaValidator.GRAPHIC_TYPE_TO_JSON_SCHEMA.get(graphicType);
        if (!graphicJsonSchema) {
            return graphicJsonSchema;
        }
        return JSON.parse(JSON.stringify(graphicJsonSchema));
    };
    /**
     * All supported graphic type to json schema mapping.
     * @static
     * @memberof GraphicSchemaValidator
     */
    GraphicSchemaValidator.GRAPHIC_TYPE_TO_JSON_SCHEMA = new Map([
        ['group', AVGGroupItemJSONSchema.JSON_SCHEMA],
        ['path', AVGPathItemJSONSchema.JSON_SCHEMA],
        ['text', AVGTextItemJSONSchema.JSON_SCHEMA],
        ['root', AVGJSONSchema.JSON_SCHEMA]
    ]);
    return GraphicSchemaValidator;
}());
exports.GraphicSchemaValidator = GraphicSchemaValidator;
//# sourceMappingURL=GraphicSchemaValidator.js.map