import { OrderedMap } from 'immutable';
/**
 * Shape of viewport profile
 * Reference: https://developer.amazon.com/en-US/docs/alexa/alexa-presentation-language/apl-viewport-property.html#shape
 * @export
 * @enum {string}
 */
export declare enum ViewportShape {
    ROUND = "round",
    RECTANGLE = "rectangle"
}
/**
 * Mode of viewport profile
 * Reference:
 * Reference:https://developer.amazon.com/en-US/docs/alexa/alexa-presentation-language/apl-viewport-property.html
 * #viewport_mode_property
 * @export
 * @enum {string}
 */
export declare enum ViewportMode {
    HUB = "hub",
    TV = "tv",
    MOBILE = "mobile",
    AUTO = "auto"
}
/**
 * Type of viewport profile
 * @export
 * @enum {string}
 */
export declare enum ViewportType {
    STANDARD = "standard",
    OVERLAY = "overlay"
}
/**
 * The interface of a viewport profile
 * @export
 * @interface IViewportProfile
 * @property {string} id - id of the viewport profile such as "hubLandscapeMedium"
 * @property {string} name - name of viewport profile such as 'Hub Landscape Medium"
 * @property {ViewportShape} shape - shape of viewport profile
 * @property {ViewportType} type - type of the viewport profile, optional for custom viewport
 * @property {ViewportMode} mode - mode of viewport profile, optional for custom viewport
 * @property {IViewportProfileSizeRange} dpSizeRange - size range in dp of viewport profile
 * @property {IViewport[]} exampleDevices - default viewports of viewport profile
 * @property {boolean} isCustom - is custom viewport profile
 *
 */
export interface IViewportProfile {
    id: string;
    name: string;
    shape: ViewportShape;
    type?: ViewportType;
    mode?: ViewportMode;
    dpSizeRange: IViewportProfileSizeRange;
    exampleDevices: IViewport[];
    isCustom?: boolean;
    label?: string;
    svgIcon?: string;
}
/**
 * The interface of a viewport
 * @export
 * @interface IViewport
 * @property {string} id - id of the viewport
 * @property {string} name - name of viewport
 * @property {number} width - width of viewport in dp
 * @property {number} height - height of viewport in dp
 * @property {number} dpi - dpi of viewport
 * @property {ViewportShape} shape - shape of viewport, optional for viewport profile defaults
 *
 */
export interface IViewport {
    id: string;
    name: string;
    width: number;
    height: number;
    dpi: number;
    shape?: ViewportShape;
    fullscreenDeviceId?: string;
    fullscreenHeight?: number;
    fullscreenWidth?: number;
    fullScreenViewportProfile?: string;
    fullScreenViewportProfileLabel?: string;
    svgIcon?: string;
    mode?: string;
}
/**
 * The interface of a viewport profile size range
 * @export
 * @interface IViewportProfileSizeRange
 * @property {number} minWidth - minimun width of viewport profile in dp
 * @property {number} maxWidth - maximum width of viewport profile in dp
 * @property {number} minHeight - minimun height of viewport profile in dp
 * @property {number} maxHeight - maximum width of viewport profile in dp
 *
 */
interface IViewportProfileSizeRange {
    minWidth: number;
    maxWidth: number;
    minHeight: number;
    maxHeight: number;
}
/**
 * Get viewport profiles.
 * @returns {OrderedMap<string, IViewportProfile>}
 */
export declare function getViewportProfiles(): OrderedMap<string, IViewportProfile>;
/**
 * Default viewport profile
 * @export
 */
export declare function getDefaultViewportProfile(): IViewportProfile;
/**
 * Default viewport
 * @export
 */
export declare function getDefaultViewport(): IViewport;
export {};
