/*
 *   Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 *   Licensed under the Apache License, Version 2.0 (the "License").
 *   You may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 */
'use strict';
Object.defineProperty(exports, "__esModule", { value: true });
exports.ErrorController = void 0;
var IErrorDefinitions_1 = require("./IErrorDefinitions");
/**
 * ErrorController is used to control the errors in the renderer, and react when they occur.
 */
var ErrorController = /** @class */ (function () {
    /**
     * Creates an instance of ErrorController.
     * @param {IErrors} errorInterface
     * @memberof ErrorController
     */
    function ErrorController(errorInterface) {
        /**
         * Maintain a mapping code=>error
         * @private
         * @type {Map<string, IError>}
         * @memberOf CommandController
         */
        this.errorMap = new Map();
        this.errorInterface = errorInterface;
        this.existingAffectedElementPathSet = new Set();
    }
    /**
     * Clear all existing validation warn.
     *
     * @memberof ErrorController
     */
    ErrorController.prototype.clearExistingWarn = function () {
        this.existingAffectedElementPathSet = new Set();
    };
    /**
     * Used to register an error
     * @param {string} id
     * @param {IError} error
     * @memberOf CommandController
     */
    ErrorController.prototype.registerError = function (error) {
        this.errorMap.set(error.code, error);
    };
    /**
     * Register all renderer specific errors
     * @memberOf CommandController
     */
    ErrorController.prototype.registerErrors = function () {
        var _this = this;
        Object.keys(IErrorDefinitions_1.ErrorDefinitions).forEach(function (key) { return _this.registerError(IErrorDefinitions_1.ErrorDefinitions[key]); });
    };
    /**
     * Triggers a runtime error.
     * @param {string} code
     * @returns
     * @memberOf ErrorController
     */
    ErrorController.prototype.triggerRuntimeError = function (code) {
        var error = this.errorMap.get(code);
        if (!error) {
            return;
        }
        this.errorInterface.sendError(error);
    };
    /**
     * Triggers a validation error.
     * @param {string} code
     * @param {object} position
     * @param {object} [placeholders={}]
     * @memberOf ErrorController
     */
    ErrorController.prototype.triggerValidationError = function (code, placeholders) {
        if (placeholders === void 0) { placeholders = {}; }
        var error = this.errorMap.get(code);
        if (!error) {
            return;
        }
        // ToDo: implement position when we have the ability
        error.placeholders = placeholders;
        this.errorInterface.sendError(error);
    };
    ErrorController.prototype.sendValidationError = function (validationError) {
        var path = validationError.placeholders['path'];
        if (this.existingAffectedElementPathSet.has(path)) {
            return;
        }
        this.existingAffectedElementPathSet.add(path);
        this.errorInterface.sendError(validationError);
    };
    /**
     * Sets instance to new ErrorController with supplied interface.
     * @static
     * @param {IErrorInterface} callback
     * @memberOf ErrorController
     */
    ErrorController.prototype.setErrorInterface = function (errorInterface) {
        this.errorInterface = errorInterface;
    };
    /**
     * Returns an instance of the ErrorController.
     * @static
     * @returns {ErrorController}
     * @memberOf ErrorController
     */
    ErrorController.getInstance = function () {
        if (this.instance) {
            return this.instance;
        }
        this.instance = new ErrorController(new DefaultErrorInterface());
        return this.instance;
    };
    return ErrorController;
}());
exports.ErrorController = ErrorController;
var DefaultErrorInterface = /** @class */ (function () {
    function DefaultErrorInterface() {
    }
    DefaultErrorInterface.prototype.sendError = function (error) { };
    return DefaultErrorInterface;
}());
//# sourceMappingURL=ErrorController.js.map