/**
 * Error levels supported by the renderer
 * @export
 * @enum {string}
 */
export declare enum ErrorLevels {
    ERROR = "ERROR",
    WARN = "WARNING"
}
/**
 * Error types supported by the renderer
 * @export
 * @enum {string}
 */
export declare enum ErrorTypes {
    RUNTIME = "RUNTIME",
    VALIDATION = "VALIDATION"
}
/**
 * Cursor position of error in APML.
 * @export
 * @interface ICursorPosition
 */
export interface ICursorPosition {
    row: number;
    column: number;
}
/**
 * @export
 * @interface IError
 */
export interface IError {
    level: ErrorLevels;
    type: ErrorTypes;
    code: string;
}
/**
 * Runtime Error Interface.
 * A runtime error is a generic error from the renderer that does
 * not reference a specific property or point in the APML template.
 * @export
 * @interface IRuntimeError
 * @extends {IError}
 */
export interface IRuntimeError extends IError {
    level: ErrorLevels.ERROR;
    type: ErrorTypes.RUNTIME;
}
/**
 * Validation Error Interface.
 * A validation error is an error specific to the APML template and can be
 * accompanied by a cursor position or message placeholders.
 * Note: Validation errors have not yet been implemented. Validation errors
 *       will always have a cursor position as they relate to the APML document.
 * @export
 * @interface IValidationError
 * @extends {IError}
 */
export interface IValidationError extends IError {
    level: ErrorLevels;
    type: ErrorTypes.VALIDATION;
    placeholders?: object;
}
/**
 * A renderer error is either a runtime or validation error.
 */
export type IRendererError = IRuntimeError | IValidationError;
