/*
 *   Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 *   Licensed under the Apache License, Version 2.0 (the "License").
 *   You may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 */
'use strict';
Object.defineProperty(exports, "__esModule", { value: true });
// tslint:disable:no-unused-expression
var sinon = require("sinon");
var chai_1 = require("chai");
var ErrorController_1 = require("../ErrorController");
var Errors = require("../IErrorDefinitions");
var IError_1 = require("../IError");
/**
 * Create an empty callback to send to ErrorController.
 * We spy this to ensure callbacks are fired correctly.
 */
var createErrorCallback = function () { return ({
    sendError: (function (error) { })
}); };
// Mocked errors that are registered in renderer
var MOCK_ERRORS = {
    MOCKED_RUNTIME_ERROR: {
        level: IError_1.ErrorLevels.ERROR,
        type: IError_1.ErrorTypes.RUNTIME,
        code: '0'
    },
    MOCKED_VALIDATION_ERROR: {
        level: IError_1.ErrorLevels.ERROR,
        type: IError_1.ErrorTypes.VALIDATION,
        code: '1'
    }
};
// An error code not in MOCK_ERRORS object
var MOCKED_ERROR_CODE_DOESNT_EXIST = '-999999';
describe('ErrorController', function () {
    var sandbox;
    var errorController;
    var errorCallback;
    beforeEach(function () {
        sandbox = sinon.sandbox.create();
        errorCallback = createErrorCallback();
        errorController = ErrorController_1.ErrorController.getInstance();
        errorController.setErrorInterface(errorCallback);
    });
    afterEach(function () {
        sandbox.restore();
    });
    describe('Runtime Errors', function () {
        it('Can register and trigger runtime errors.', function () {
            var callbackSpy = sandbox.spy(errorCallback, 'sendError');
            sandbox.stub(Errors, 'ErrorDefinitions', MOCK_ERRORS);
            errorController.registerErrors();
            errorController.triggerRuntimeError(MOCK_ERRORS.MOCKED_RUNTIME_ERROR.code);
            (0, chai_1.expect)(callbackSpy.calledWith(MOCK_ERRORS.MOCKED_RUNTIME_ERROR)).to.be.true;
        });
        it('Does not trigger a runtime error that hasnt been registered', function () {
            var callbackSpy = sandbox.spy(errorCallback, 'sendError');
            sandbox.stub(Errors, 'ErrorDefinitions', MOCK_ERRORS);
            errorController.registerErrors();
            errorController.triggerRuntimeError(MOCKED_ERROR_CODE_DOESNT_EXIST);
            (0, chai_1.expect)(callbackSpy.calledOnce).to.be.false;
        });
    });
    describe('Validation Errors', function () {
        it('Can register and trigger validation errors', function () {
            var callbackSpy = sandbox.spy(errorCallback, 'sendError');
            sandbox.stub(Errors, 'ErrorDefinitions', MOCK_ERRORS);
            errorController.registerErrors();
            errorController.triggerValidationError(MOCK_ERRORS.MOCKED_VALIDATION_ERROR.code);
            (0, chai_1.expect)(callbackSpy.calledWith(MOCK_ERRORS.MOCKED_VALIDATION_ERROR)).to.be.true;
        });
        it('Can register and trigger validation errors with placeholders', function () {
            var callbackSpy = sandbox.spy(errorCallback, 'sendError');
            sandbox.stub(Errors, 'ErrorDefinitions', MOCK_ERRORS);
            errorController.registerErrors();
            var placeholders = { key: 'test' };
            var expectedResult = MOCK_ERRORS.MOCKED_VALIDATION_ERROR;
            expectedResult.placeholders = placeholders;
            errorController.triggerValidationError(MOCK_ERRORS.MOCKED_VALIDATION_ERROR.code, placeholders);
            (0, chai_1.expect)(callbackSpy.calledWith(expectedResult)).to.be.true;
        });
    });
});
//# sourceMappingURL=ErrorController.spec.js.map