/*
 *   Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 *   Licensed under the Apache License, Version 2.0 (the "License").
 *   You may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 */
'use strict';
Object.defineProperty(exports, "__esModule", { value: true });
exports.AplComponentsExtractor = void 0;
var JsonPathCompletor_1 = require("./JsonPathCompletor");
var IErrorDefinitions_1 = require("../errors/IErrorDefinitions");
var ErrorController_1 = require("../errors/ErrorController");
var PrimitiveComponentJsonSchemaUtil_1 = require("./PrimitiveComponentJsonSchemaUtil");
/**
 * Used to extract components from APL template.
 * @export
 * @class AplComponentsExtractor
 */
var AplComponentsExtractor = /** @class */ (function () {
    function AplComponentsExtractor() {
        this.ROOT_COMPONENT_TYPE = 'mainTemplate';
    }
    /**
     * Singleton method.
     *
     * @static
     * @returns {AplComponentsExtractor}
     * @memberof AplComponentsExtractor
     */
    AplComponentsExtractor.getInstance = function () {
        if (!this.instance) {
            this.instance = new AplComponentsExtractor();
        }
        return this.instance;
    };
    /**
     * Extract component from current APL template without parsing all components defined in import.
     * @param {object} aplTemplate
     * @returns {IAplComponent[]}
     * @memberof AplComponentsExtractor
     */
    AplComponentsExtractor.prototype.extractComponents = function (aplTemplate) {
        var _this = this;
        var components = [];
        // add json path through completor. The completor also did deep copy of aplTemplate.
        var aplTemplateWithPath = new JsonPathCompletor_1.JsonPathCompletor(aplTemplate).addJsonPath();
        // add components under layouts
        if (aplTemplateWithPath['layouts']) {
            Object.keys(aplTemplateWithPath['layouts']).forEach(function (key) {
                _this.addComponent(aplTemplateWithPath['layouts'][key], { type: key }, components);
            });
        }
        // add mainTemplate components
        if (aplTemplateWithPath['mainTemplate']) {
            this.addComponent(aplTemplateWithPath['mainTemplate'], { type: this.ROOT_COMPONENT_TYPE }, components);
        }
        // mixin parentComponentType
        var aplComponentTypes = PrimitiveComponentJsonSchemaUtil_1.PrimitiveComponentJsonSchemaUtil
            .getPrimitiveComponentTypes(aplTemplate['version']);
        this.generateMixinParent(components, aplComponentTypes);
        return components;
    };
    /**
     * Add current component. Also add child components if there are any.
     * @param component the current component to add
     * @param parentType direct parentType. Used to find mixin parent type later.
     * @param existingComponents list of AplComponents
     */
    AplComponentsExtractor.prototype.addComponent = function (component, parentComponent, existingComponents) {
        var newParentComponent = component['type'] ? component : parentComponent;
        if (component['items']) {
            this.addChildComponents(component['items'], newParentComponent, existingComponents);
        }
        if (component['item']) {
            this.addChildComponents(component['item'], newParentComponent, existingComponents);
        }
        var aplComponent = this.buildAplComponent(component, parentComponent);
        existingComponents.push(aplComponent);
    };
    AplComponentsExtractor.prototype.addChildComponents = function (childComponents, parentComponent, existingComponents) {
        var _this = this;
        if (Array.isArray(childComponents)) {
            childComponents.forEach(function (component) { return _this.addComponent(component, parentComponent, existingComponents); });
        }
        else if (typeof (childComponents) === 'object') {
            this.addComponent(childComponents, parentComponent, existingComponents);
        }
    };
    AplComponentsExtractor.prototype.buildAplComponent = function (rawComponent, parentComponent) {
        var jsonPath = rawComponent[JsonPathCompletor_1.JsonPathCompletor.JSON_PATH];
        // delete unrelated properties
        delete rawComponent[JsonPathCompletor_1.JsonPathCompletor.JSON_PATH];
        if (rawComponent['items'] && rawComponent['item']) {
            var errorController = ErrorController_1.ErrorController.getInstance();
            errorController.triggerValidationError(IErrorDefinitions_1.ErrorDefinitions.COMPONENT_BUILDER_ITEM_AND_ITEMS.code, { path: jsonPath });
        }
        // indicate whether item/items exists but don't return the children. This replaced
        // outright deleting the properties which meant they would always error when required.
        if (rawComponent['item']) {
            rawComponent['item'] = [];
        }
        if (rawComponent['items']) {
            rawComponent['items'] = [];
        }
        return {
            jsonObject: rawComponent,
            jsonPath: jsonPath,
            componentType: this.isExtensionComponent(rawComponent['type'])
                ? 'ExtensionComponent' : rawComponent['type'],
            parentComponentType: this.isExtensionComponent(parentComponent['type'])
                ? 'ExtensionComponent' : parentComponent['type'],
            parentComponent: parentComponent
        };
    };
    AplComponentsExtractor.prototype.isExtensionComponent = function (type) {
        var regex = new RegExp('^\\w+:\\w+$');
        return regex.test(type);
    };
    AplComponentsExtractor.prototype.generateMixinParent = function (components, aplComponentTypes) {
        var _this = this;
        components.forEach(function (component) {
            component.parentComponent = _this.findMixinParent(component.parentComponent, components, aplComponentTypes);
            component.parentComponentType = component.parentComponent['type'];
        });
    };
    AplComponentsExtractor.prototype.findMixinParent = function (currentParent, components, aplComponentTypes) {
        // Already reach root or the parent is APL component already
        if (currentParent['type'] === this.ROOT_COMPONENT_TYPE || aplComponentTypes.includes(currentParent['type'])) {
            return currentParent;
        }
        var parentComponent = components.filter(function (c) {
            // avoid dead loop when a component's parent is the same type of itself
            // for layouts/custom/item is custom
            // currentParent is { "type": "custom"}, component is { "type": "custom" }
            if (c.componentType === c.parentComponentType) {
                return false;
            }
            return c.componentType === currentParent['type'];
        }).shift();
        if (parentComponent === undefined
            || parentComponent.parentComponent === undefined
            || !parentComponent.parentComponent['type']) {
            // The parent component is not used in APL.
            return currentParent;
        }
        else {
            return this.findMixinParent(parentComponent.parentComponent, components, aplComponentTypes);
        }
    };
    return AplComponentsExtractor;
}());
exports.AplComponentsExtractor = AplComponentsExtractor;
//# sourceMappingURL=AplComponentsExtractor.js.map