/*
 *   Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 *   Licensed under the Apache License, Version 2.0 (the "License").
 *   You may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 */
'use strict';
Object.defineProperty(exports, "__esModule", { value: true });
exports.JsonPathCompletor = void 0;
/**
 * This class is used to add json path to meta template.
 */
var JsonPathCompletor = /** @class */ (function () {
    /**
     * Creates an instance of JsonPathCompletor.
     * @param {object} originalDoc
     * @memberof JsonPathCompletor
     */
    function JsonPathCompletor(originalDoc, key) {
        this.keyToAdd = key ? key : JsonPathCompletor.JSON_PATH;
        this.copiedDoc = JSON.parse(JSON.stringify(originalDoc));
    }
    /**
     * Add json path to template object.
     * @returns {object} with json path information.
     * @memberof JsonPathCompletor
     */
    JsonPathCompletor.prototype.addJsonPath = function () {
        var layoutElement = this.copiedDoc['layouts'];
        if (layoutElement) {
            for (var _i = 0, _a = Object.keys(layoutElement); _i < _a.length; _i++) {
                var eachKey = _a[_i];
                this.addJsonPathToObject(layoutElement[eachKey], "/layouts/".concat(eachKey));
            }
        }
        if (this.copiedDoc['mainTemplate']) {
            this.addJsonPathToObject(this.copiedDoc['mainTemplate'], '/mainTemplate');
        }
        return this.copiedDoc;
    };
    /**
     * Add json path to grpahics object.
     * @returns {object} with json path information in graphics.
     * @memberof JsonPathCompletor
     */
    JsonPathCompletor.prototype.addJsonPathToGraphics = function () {
        var graphicsElement = this.copiedDoc['graphics'];
        if (graphicsElement) {
            for (var _i = 0, _a = Object.keys(graphicsElement); _i < _a.length; _i++) {
                var eachKey = _a[_i];
                this.addJsonPathToObject(graphicsElement[eachKey], "/graphics/".concat(eachKey));
            }
        }
        return this.copiedDoc;
    };
    /**
     * Recursion method to add json path to template.
     * @private
     * @param {object} currentObject
     * @param {string} currentPath
     * @returns
     * @memberof JsonPathCompletor
     */
    JsonPathCompletor.prototype.addJsonPathToObject = function (currentObject, currentPath) {
        if (typeof (currentObject) !== 'object') {
            return;
        }
        currentObject[this.keyToAdd] = currentPath;
        this.processChildComponent(currentObject, currentPath, 'items');
        this.processChildComponent(currentObject, currentPath, 'item');
    };
    /**
     * Process child element under item(s).
     * @private
     * @param {object} currentObject
     * @param {string} currentPath
     * @param {string} element
     * @memberof JsonPathCompletor
     */
    JsonPathCompletor.prototype.processChildComponent = function (currentObject, currentPath, element) {
        if (!currentObject[element]) {
            return;
        }
        if (Array.isArray(currentObject[element])) {
            var index = 0;
            for (var _i = 0, _a = currentObject[element]; _i < _a.length; _i++) {
                var eachArrayElem = _a[_i];
                this.addJsonPathToObject(eachArrayElem, currentPath + "/".concat(element, "/").concat(index));
                index += 1;
            }
        }
        else if (typeof (currentObject[element]) === 'object') {
            this.addJsonPathToObject(currentObject[element], currentPath + "/".concat(element));
        }
    };
    /**
     * JSON path key.
     * @static
     * @memberof JsonPathCompletor
     */
    JsonPathCompletor.JSON_PATH = 'JSON_PATH';
    return JsonPathCompletor;
}());
exports.JsonPathCompletor = JsonPathCompletor;
//# sourceMappingURL=JsonPathCompletor.js.map