/**
 *
 * Package loading theory.
 * 1. We start with a list of packages required.
 * 2. Each package in the list can be in one of the following states:
 *    a. Unloaded (not started yet)
 *    b. Loading (waiting for a response from the server)
 *    c. Loaded (waiting for a child to load)
 *    d. Finished (all children have loaded)
 *
 * @export
 * @class PackageLoader
 */
export declare class PackageLoader {
    /**
     * The package json file provided by the user
     * @private
     * @type {object}
     * @memberOf PackageLoader
     */
    private embeddedPackages;
    /**
     * The invalid imported packages
     * @private
     * @type {string[]} An array that holds all names of invalid imported packages
     * @memberOf PackageLoader
     */
    private invalidPackages;
    /**
     * The packages map connects package name to data. It stores:
     *     name -> { json: JSON,
     *               state: load|loadChildren|done,
     *               loadSeries: NUMBER,
     *             }
     *
     * @private
     * @type {Map<string, ILoadingProcessData>}
     * @memberOf PackageLoader
     */
    private loadPackages;
    /**
     * The number of loading times
     * @private
     * @type {number}
     * @memberOf PackageLoader
     */
    private loadSeries;
    /**
     * Initialize PackageLoader attributes
     *
     * @param {object} embeddedPackages The package json file provided by the user
     *
     * @memberOf PackageLoader
     */
    constructor(embeddedPackages: object);
    /**
     *   Load import packages
     */
    load(importPackages: any[]): Promise<ILoadedResult[]>;
    /**
     * Flush loaded packages
     */
    flush(): void;
    /**
     * Walk a list of packages until all of them have been loaded.
     */
    private ensureLoaded;
    /**
     * Check if version is a prod version
     * Version string shouldn't match staging version pattern: eg. 1.4.0-sadhsagfydavchgah
     */
    private isProdVersion;
    /**
     * Execute a package load.  For now we ignore version
     */
    private loadPackage;
    /**
     *  Walk a list of packages and return all dependencies in order.
     *  Those two functions are following the depth-first search, following the package import order.
     */
    private orderedPackageNames;
    /**
     *   Embeded function for orderedPackageNames.
     *   Depth first search a list of packages and return all dependencies in order.
     */
    private addPackageNames;
    private namesToData;
    /**
     *   Deep-freeze object to ensure JSON is never modified
     */
    private deepFreeze;
}
/**
 * During loading packages, use ILoadingProcessData to track loading process
 *
 * @export
 * @interface ILoadingProcessData
 */
export interface ILoadingProcessData {
    json: object;
    state: LoadState;
    loadSeries: number;
    error?: any;
}
/**
 * Loading process contains:
 * - load : start loading this package
 * - loadChildren : start loading the children of this package
 * - done : finish loading this package
 *
 * @export
 * @enum {number}
 */
export declare enum LoadState {
    load,
    loadChildren,
    done
}
/**
 * The actual data structure that will be returned by the packageLoader.
 *
 * @export
 * @interface ILoadedResult
 */
export interface ILoadedResult {
    name: string;
    json: object;
    justLoaded: boolean;
    error: any;
}
