"use strict";
/*
 *   Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 *   Licensed under the Apache License, Version 2.0 (the "License").
 *   You may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.ValidationErrorFilter = void 0;
var VariableStringChecker_1 = require("./VariableStringChecker");
var ValidationErrorFilter = /** @class */ (function () {
    function ValidationErrorFilter() {
    }
    /**
     * Collapse oneOf fields. When using oneOf, AJV will return multiple errors (one more than the number
     * of required fields). This method collapses those errors into the root error and modifies the root
     * error message to list required fields.
     * @private
     * @param {object[]} errors
     * @returns {object[]}
     * @memberOf ValidationErrorFilter
     */
    ValidationErrorFilter.collapseOneOfSchemaProperties = function (errors) {
        var oneOfSchemaPath = '#/oneOf';
        var oneOfRootError = errors.find(function (error) { return error.schemaPath === oneOfSchemaPath; });
        if (!oneOfRootError) {
            return errors;
        }
        // collapse oneOf fields and store missing properties for message creation.
        var oneOfSchemaSet = [];
        errors = errors.filter(function (error) {
            if (!error.schemaPath.includes(oneOfSchemaPath)) {
                return true;
            }
            if (error.params.missingProperty) {
                oneOfSchemaSet.push(error.params.missingProperty);
            }
            return false;
        });
        // customize message
        oneOfRootError.message = "missing required field: ".concat(oneOfSchemaSet.join(' or '));
        errors = errors.concat(oneOfRootError);
        return errors;
    };
    /**
     * Filter errors pointing to the parent error node out, only need the leaf error node.
     * @public
     * @param {object[]} errors
     * @returns {object[]}
     * @memberof ValidationErrorFilter
     */
    ValidationErrorFilter.filterErrors = function (errors, singlePathFilter) {
        var _this = this;
        errors = this.collapseOneOfSchemaProperties(errors);
        // First filter out all Boolean type errors whose value is an valid variable expression
        var processedErrorsWithoutBooleanType = this.processBooleanTypeErrors(errors);
        var errorPathSet = [];
        processedErrorsWithoutBooleanType.forEach(function (element) {
            errorPathSet.push(element['dataPath']);
        });
        var onlyChildrenNodePathArray = processedErrorsWithoutBooleanType.filter(function (element, index, array) {
            var dataPath = element['dataPath'];
            if (dataPath === '') {
                return true;
            }
            for (var _i = 0, errorPathSet_1 = errorPathSet; _i < errorPathSet_1.length; _i++) {
                var eachPath = errorPathSet_1[_i];
                if (eachPath !== dataPath && _this.isNodeOf(dataPath, eachPath)) {
                    return false;
                }
            }
            return true;
        });
        if (singlePathFilter) {
            return this.processErrors(singlePathFilter(onlyChildrenNodePathArray));
        }
        return this.processErrors(onlyChildrenNodePathArray);
    };
    /**
     * Filter the errors out if the value defined as a variable.
     * @private
     * @param {object[]} errors
     * @returns {object[]}
     * @memberof ValidationErrorFilter
     */
    ValidationErrorFilter.processErrors = function (errors) {
        return errors.filter(function (eachError) {
            var actualValue = eachError['data'];
            if (actualValue && typeof (actualValue) === 'string') {
                if ((0, VariableStringChecker_1.containsVariableString)(actualValue)) {
                    return false;
                }
            }
            return true;
        });
    };
    /**
     * Filter the boolean type errors out if the value defined as a variable.
     * @private
     * @param {object[]} errors
     * @returns {object[]}
     * @memberof ValidationErrorFilter
     */
    ValidationErrorFilter.processBooleanTypeErrors = function (errors) {
        return errors.filter(function (eachError) {
            var schemaType = eachError['schema'];
            var actualValue = eachError['data'];
            if (schemaType === 'boolean' && actualValue && typeof (actualValue) === 'string') {
                if ((0, VariableStringChecker_1.containsVariableString)(actualValue)) {
                    return false;
                }
            }
            return true;
        });
    };
    ValidationErrorFilter.isNodeOf = function (existingPath, pathToCheck) {
        return pathToCheck.startsWith(existingPath);
    };
    ValidationErrorFilter.userDefinedPropertyPrefix = '-user-';
    /**
     * Filter out duplicated path if dataPath is empty ignore.
     * @static
     * @memberof ValidationErrorFilter
     */
    ValidationErrorFilter.singleDataPathFilterNoRootPath = function (noChildrenPathArray) {
        var result = new Set();
        return noChildrenPathArray.filter(function (item) {
            if (item['dataPath'] === '') {
                return true;
            }
            if (!result.has(item['dataPath'])) {
                result.add(item['dataPath']);
                return true;
            }
            return false;
        });
    };
    /**
     * Filter out duplicated path.
     * @static
     * @memberof ValidationErrorFilter
     */
    ValidationErrorFilter.singleDataPathFilter = function (noChildrenPathArray) {
        var result = new Set();
        return noChildrenPathArray.filter(function (item) {
            if (!result.has(item['dataPath'])) {
                result.add(item['dataPath']);
                return true;
            }
            return false;
        });
    };
    ValidationErrorFilter.userDefinedPropertyErrorFilter = function (error) {
        if (!error['params']
            || !error['params']['additionalProperty']
            || typeof error['params']['additionalProperty'] !== 'string') {
            return true;
        }
        var isUserDefinedPropertyError = error['params']['additionalProperty']
            .startsWith(ValidationErrorFilter.userDefinedPropertyPrefix);
        return !isUserDefinedPropertyError;
    };
    return ValidationErrorFilter;
}());
exports.ValidationErrorFilter = ValidationErrorFilter;
//# sourceMappingURL=ValidationErrorFilter.js.map