"use strict";
/*
 *   Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 *   Licensed under the Apache License, Version 2.0 (the "License").
 *   You may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
var chai_1 = require("chai");
var AplComponentsExtractor_1 = require("../AplComponentsExtractor");
describe('AplComponentsExtractor tests', function () {
    var APL_DOC = {
        mainTemplate: {
            items: {
                type: 'ListTemplate1'
            }
        },
        layouts: {
            ListTemplate1: {
                item: [
                    {
                        type: 'Sequence',
                        items: [
                            {
                                type: 'VerticalListItem'
                            }
                        ]
                    },
                    {
                        type: 'Extension:Component'
                    }
                ]
            },
            VerticalListItem: {
                item: {
                    type: 'Container',
                    items: [
                        {
                            type: 'Text'
                        }
                    ]
                }
            },
            UnusedItem: {
                item: {
                    type: 'Image'
                }
            }
        }
    };
    var APL_DOC_WITH_CUSTOM_LAYOUT_CONTAINS_SELF = {
        layouts: {
            custom: {
                item: {
                    type: 'custom'
                }
            }
        },
        mainTemplate: {
            parameters: [
                'payload'
            ],
            items: [
                {
                    type: 'Container',
                    items: [
                        {
                            type: 'custom'
                        }
                    ]
                }
            ]
        }
    };
    var aplComponentsExtractor = AplComponentsExtractor_1.AplComponentsExtractor.getInstance();
    it('should be able to extract all components from requested APL template', function () {
        var components = aplComponentsExtractor.extractComponents(APL_DOC);
        // the component count should be expected
        (0, chai_1.expect)(components.length).to.be.equal(11);
        // all components should contain jsonPath
        (0, chai_1.expect)(components.filter(function (c) { return c.jsonPath === undefined; })).to.have.lengthOf(0);
        // the component parent should be expected.
        (0, chai_1.expect)(components.filter(function (c) { return c.parentComponentType === undefined; })).to.have.lengthOf(0);
        (0, chai_1.expect)(components.filter(function (c) { return c.componentType === 'Text'; })[0].parentComponentType).to.be.equal('Container');
        (0, chai_1.expect)(components.filter(function (c) { return c.componentType === 'Sequence'; })[0].parentComponentType)
            .to.be.equal('mainTemplate');
        (0, chai_1.expect)(components.filter(function (c) { return c.componentType === 'Container'; })[0].parentComponentType)
            .to.be.equal('Sequence');
        (0, chai_1.expect)(components.filter(function (c) { return c.componentType === 'ExtensionComponent'; })[0].parentComponentType)
            .to.be.equal('mainTemplate');
    });
    it('should still success for undefined layout or mainTemplate', function () {
        var aplWithoutMainTemplate = JSON.parse(JSON.stringify(APL_DOC));
        delete aplWithoutMainTemplate.mainTemplate;
        var componentsWithoutMainTemplate = aplComponentsExtractor.extractComponents(aplWithoutMainTemplate);
        (0, chai_1.expect)(componentsWithoutMainTemplate.length).to.be.equal(9);
        var aplWithoutLayout = JSON.parse(JSON.stringify(APL_DOC));
        delete aplWithoutLayout.layouts;
        var componentsWithoutLayout = aplComponentsExtractor.extractComponents(aplWithoutLayout);
        (0, chai_1.expect)(componentsWithoutLayout.length).to.be.equal(2);
    });
    it('should not throws with custom layout contains self', function () {
        var components = aplComponentsExtractor.extractComponents(APL_DOC_WITH_CUSTOM_LAYOUT_CONTAINS_SELF);
        (0, chai_1.expect)(components.length).to.be.equal(5);
        (0, chai_1.expect)(components.filter(function (c) { return c.jsonPath === undefined; })).to.have.lengthOf(0);
        (0, chai_1.expect)(components.filter(function (c) { return c.parentComponentType === undefined; })).to.have.lengthOf(0);
        (0, chai_1.expect)(components.filter(function (c) { return c.componentType === 'custom'; })[0].parentComponentType).to.be.equal('Container');
        (0, chai_1.expect)(components.filter(function (c) { return c.componentType === 'Container'; })[0].parentComponentType)
            .to.be.equal('mainTemplate');
    });
});
//# sourceMappingURL=AplComponentsExtractor.spec.js.map