"use strict";
/*
 *   Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 *   Licensed under the Apache License, Version 2.0 (the "License").
 *   You may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
var chai_1 = require("chai");
var ValidationErrorFilter_1 = require("../ValidationErrorFilter");
var MOCK_ANYOF_ERRORS = [
    {
        dataPath: '',
        keyword: 'required',
        message: 'should have required property "item"',
        params: { missingProperty: 'item' },
        schema: ['type', 'item'],
        schemaPath: '#/oneOf/0/required'
    },
    {
        dataPath: '',
        keyword: 'required',
        message: 'should have required property "items"',
        params: { missingProperty: 'items' },
        schema: ['type', 'items'],
        schemaPath: '#/oneOf/1/required'
    },
    {
        dataPath: '',
        keyword: 'required',
        message: 'should match some schema in oneOf',
        params: {},
        schema: [
            { required: ['type', 'item'] },
            { required: ['type', 'items'] }
        ],
        schemaPath: '#/oneOf'
    }
];
var MOCK_PATH_ERRORS = [
    {
        dataPath: '/version',
        keyword: 'required',
        message: 'should have required property "item"',
        params: { missingProperty: 'item' },
        schema: ['type', 'item'],
        schemaPath: 'enum'
    },
    {
        dataPath: 'graphics/version',
        keyword: 'required',
        message: 'should have required property "items"',
        params: { missingProperty: 'items' },
        schema: ['type', 'items'],
        schemaPath: 'enum'
    },
    {
        dataPath: 'graphics',
        keyword: 'required',
        message: 'should have required property "items"',
        params: { missingProperty: 'items' },
        schema: ['type', 'items'],
        schemaPath: 'enum'
    }
];
var MOCK_ADDITIONAL_PROPERTIES_ERRORS = [
    {
        dataPath: '',
        keyword: 'additionalProperties',
        message: 'should NOT have additional properties',
        params: {
            additionalProperty: '-user-position'
        },
        schema: false,
        schemaPath: '#/additionalProperties'
    },
    {
        dataPath: '',
        keyword: 'additionalProperties',
        message: 'should NOT have additional properties',
        params: {
            additionalProperty: 'mock-position'
        },
        schema: false,
        schemaPath: '#/additionalProperties'
    }
];
describe('ValidationErrorFilter', function () {
    it('should correctly collapse oneOf item/items schema errors.', function () {
        var actualResults = [];
        ValidationErrorFilter_1.ValidationErrorFilter.filterErrors(MOCK_ANYOF_ERRORS, ValidationErrorFilter_1.ValidationErrorFilter.singleDataPathFilter).forEach(function (error) {
            actualResults.push(error);
        });
        (0, chai_1.expect)(actualResults.length).to.equal(1);
    });
    it('should filter user defined property errors.', function () {
        var actualResults = [];
        MOCK_ADDITIONAL_PROPERTIES_ERRORS.filter(ValidationErrorFilter_1.ValidationErrorFilter.userDefinedPropertyErrorFilter)
            .forEach(function (error) {
            actualResults.push(error);
        });
        (0, chai_1.expect)(actualResults.length).to.equal(1);
    });
    it('should correctly collapse oneOf item/items schema errors.', function () {
        var actualResults = [];
        ValidationErrorFilter_1.ValidationErrorFilter.filterErrors(MOCK_PATH_ERRORS, ValidationErrorFilter_1.ValidationErrorFilter.singleDataPathFilter).forEach(function (error) {
            actualResults.push(error);
        });
        (0, chai_1.expect)(actualResults.length).to.equal(2);
    });
});
//# sourceMappingURL=ValidationErrorFilter.spec.js.map