/*
 *   Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 *   Licensed under the Apache License, Version 2.0 (the "License").
 *   You may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 */
'use strict';
Object.defineProperty(exports, "__esModule", { value: true });
exports.AplCommandsExtractor = void 0;
var JsonPathCompletor_1 = require("../JsonPathCompletor");
/**
 * Used to extract Commands from APL template.
 * @export
 * @class AplCommandsExtractor
 */
var AplCommandsExtractor = /** @class */ (function () {
    function AplCommandsExtractor() {
    }
    /**
     * Singleton method.
     *
     * @static
     * @returns {AplCommandsExtractor}
     * @memberof AplCommandsExtractor
     */
    AplCommandsExtractor.getInstance = function () {
        if (!this.instance) {
            this.instance = new AplCommandsExtractor();
        }
        return this.instance;
    };
    /**
     * Extract Command from current APL template without parsing all Commands defined in import.
     * @param {object} aplTemplate
     * @returns {IAplCommand[]}
     * @memberof AplCommandsExtractor
     */
    AplCommandsExtractor.prototype.extractCommands = function (aplTemplate) {
        var _this = this;
        var commands = [];
        // add json path through completor. The completor also did deep copy of aplTemplate.
        var aplTemplateWithPath = this.addJsonPath(aplTemplate);
        // add commands under commands
        if (aplTemplateWithPath['commands']) {
            Object.values(aplTemplateWithPath['commands'])
                .filter(function (value) { return typeof (value) === 'object'; })
                .forEach(function (value) {
                _this.addCommandArray(value, commands, '');
            });
        }
        AplCommandsExtractor.ARRAY_OF_COMMAND_PROPERTIES.forEach(function (property) {
            _this.addChildCommands(aplTemplateWithPath[property], commands);
        });
        return commands;
    };
    /**
     * Add current Command. Also add child Commands if there are any.
     * @param Command the current Command to add
     * @param existingCommands list of AplCommands
     */
    AplCommandsExtractor.prototype.addCommand = function (command, existingCommands) {
        this.addCommandArray(command, existingCommands, command['type']);
        var aplCommand = this.buildAplCommand(command);
        existingCommands.push(aplCommand);
    };
    AplCommandsExtractor.prototype.addCommandArray = function (command, existingCommands, commandType) {
        var _this = this;
        this.getCommandsProperties(commandType).forEach(function (commandsProperty) {
            if (command[commandsProperty]) {
                _this.addChildCommands(command[commandsProperty], existingCommands);
            }
        });
    };
    AplCommandsExtractor.prototype.addChildCommands = function (childCommands, existingCommands) {
        var _this = this;
        if (Array.isArray(childCommands)) {
            childCommands.forEach(function (Command) { return _this.addCommand(Command, existingCommands); });
        }
        else if (typeof (childCommands) === 'object') {
            this.addCommand(childCommands, existingCommands);
        }
    };
    AplCommandsExtractor.prototype.buildAplCommand = function (rawCommand) {
        var jsonPath = rawCommand[JsonPathCompletor_1.JsonPathCompletor.JSON_PATH];
        // delete unrelated properties
        delete rawCommand[JsonPathCompletor_1.JsonPathCompletor.JSON_PATH];
        var commandType = rawCommand['type'];
        // indicate whether item/items exists but don't return the children. This replaced
        // outright deleting the properties which meant they would always error when required.
        this.getCommandsProperties(commandType).forEach(function (commandsProperty) {
            if (rawCommand[commandsProperty]) {
                rawCommand[commandsProperty] = [];
            }
        });
        return {
            jsonObject: rawCommand,
            jsonPath: jsonPath,
            commandType: commandType
        };
    };
    AplCommandsExtractor.prototype.getCommandsProperties = function (commandType) {
        // command property in ControlMedia is enumerated value,
        // which is the operation that should be performed on the media player.
        if (commandType === 'ControlMedia') {
            return [];
        }
        return AplCommandsExtractor.COMMANDS_PROPERTIES_MAP.get(commandType) || ['command', 'commands'];
    };
    /**
     * Add json path to commands object.
     * @returns {object} with json path information in commands.
     * @memberof JsonPathCompletor
     */
    AplCommandsExtractor.prototype.addJsonPath = function (originalDoc) {
        var _this = this;
        var copiedDoc = JSON.parse(JSON.stringify(originalDoc));
        var commandsElement = copiedDoc['commands'];
        if (commandsElement) {
            for (var _i = 0, _a = Object.keys(commandsElement); _i < _a.length; _i++) {
                var eachKey = _a[_i];
                this.addJsonPathToObject(commandsElement[eachKey], "/commands/".concat(eachKey));
            }
        }
        AplCommandsExtractor.ARRAY_OF_COMMAND_PROPERTIES.forEach(function (property) {
            if (copiedDoc[property]) {
                _this.processChildCommand(copiedDoc, '', property);
            }
        });
        return copiedDoc;
    };
    /**
     * Recursion method to add json path to template.
     * @private
     * @param {object} currentObject
     * @param {string} currentPath
     * @returns
     */
    AplCommandsExtractor.prototype.addJsonPathToObject = function (currentObject, currentPath) {
        var _this = this;
        if (typeof (currentObject) !== 'object') {
            return;
        }
        currentObject[JsonPathCompletor_1.JsonPathCompletor.JSON_PATH] = currentPath;
        this.getCommandsProperties(currentObject['type']).forEach(function (commandsProperty) {
            _this.processChildCommand(currentObject, currentPath, commandsProperty);
        });
    };
    /**
     * Process child element under commandsProperties.
     * @private
     * @param {object} currentObject
     * @param {string} currentPath
     * @param {string} element
     */
    AplCommandsExtractor.prototype.processChildCommand = function (currentObject, currentPath, element) {
        if (!currentObject[element]) {
            return;
        }
        if (Array.isArray(currentObject[element])) {
            var index = 0;
            for (var _i = 0, _a = currentObject[element]; _i < _a.length; _i++) {
                var eachArrayElem = _a[_i];
                this.addJsonPathToObject(eachArrayElem, currentPath + "/".concat(element, "/").concat(index));
                index += 1;
            }
        }
        else if (typeof (currentObject[element]) === 'object') {
            this.addJsonPathToObject(currentObject[element], currentPath + "/".concat(element));
        }
    };
    /**
     * All supported primitive component type to json schema mapping.
     * @static
     * @memberof PrimitiveComponentJsonSchemaUtil
     */
    AplCommandsExtractor.COMMANDS_PROPERTIES_MAP = new Map([
        ['Sequential', ['catch', 'commands', 'finally']],
        ['Parallel', ['commands']],
        ['OpenURL', ['onFail']],
        ['Select', ['commands', 'otherwise']]
    ]);
    AplCommandsExtractor.ARRAY_OF_COMMAND_PROPERTIES = ['onConfigChange', 'onDisplayStateChange', 'onMount'];
    return AplCommandsExtractor;
}());
exports.AplCommandsExtractor = AplCommandsExtractor;
//# sourceMappingURL=AplCommandsExtractor.js.map