/*
 *   Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 *   Licensed under the Apache License, Version 2.0 (the "License").
 *   You may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 */
'use strict';
Object.defineProperty(exports, "__esModule", { value: true });
var chai_1 = require("chai");
var ValidationSeed_1 = require("../../ValidationSeed");
var MultiChildComponentValidator_1 = require("../MultiChildComponentValidator");
describe('MultiChildComponentValidator', function () {
    var multiChildComponentValidator;
    beforeEach(function () {
        multiChildComponentValidator = new MultiChildComponentValidator_1.MultiChildComponentValidator();
    });
    it('should not report if parent is not multiChild component', function () {
        var seedComponent = new ValidationSeed_1.ValidationSeed(new ValidationSeed_1.Seed({ type: 'Text' }, '/path/to/parent/items/1'), new ValidationSeed_1.Seed({
            type: 'Text',
            item: [],
            data: {}
        }, '/path/to/parent'));
        var results = multiChildComponentValidator.validate(seedComponent);
        (0, chai_1.expect)(results.length).to.be.equal(0);
    });
    it('should not report if parent is multiChild component but no live data', function () {
        var seedComponent = new ValidationSeed_1.ValidationSeed(new ValidationSeed_1.Seed({ type: 'Text' }, '/path/to/parent/items/1'), new ValidationSeed_1.Seed({
            type: 'Container',
            item: []
        }, '/path/to/parent'));
        var results = multiChildComponentValidator.validate(seedComponent);
        (0, chai_1.expect)(results.length).to.be.equal(0);
    });
    it('should not report if parent is multiChild component but seed is not the second child item', function () {
        var seedComponent = new ValidationSeed_1.ValidationSeed(new ValidationSeed_1.Seed({ type: 'Text' }, '/path/to/parent/items/3'), new ValidationSeed_1.Seed({
            type: 'Container',
            item: [],
            data: {}
        }, '/path/to/parent'));
        var results = multiChildComponentValidator.validate(seedComponent);
        (0, chai_1.expect)(results.length).to.be.equal(0);
    });
    it('should not report if parent is multiChild component but seed is first child item', function () {
        var seedComponent = new ValidationSeed_1.ValidationSeed(new ValidationSeed_1.Seed({ type: 'Text' }, '/path/to/parent/items/0'), new ValidationSeed_1.Seed({
            type: 'Container',
            item: [],
            data: {}
        }, '/path/to/parent'));
        var results = multiChildComponentValidator.validate(seedComponent);
        (0, chai_1.expect)(results.length).to.be.equal(0);
    });
    it('should report if parent is multiChild component with live data - item', function () {
        var seedComponent = new ValidationSeed_1.ValidationSeed(new ValidationSeed_1.Seed({ type: 'Text' }, '/path/to/parent/item/1'), new ValidationSeed_1.Seed({
            type: 'Container',
            item: [],
            data: {}
        }, '/path/to/parent'));
        var results = multiChildComponentValidator.validate(seedComponent);
        (0, chai_1.expect)(results.length).to.be.equal(1);
        (0, chai_1.expect)(results[0].path).to.be.equal('/path/to/parent/item/1');
    });
    it('should report if type is multiChild component with live data - items', function () {
        var seedComponent = new ValidationSeed_1.ValidationSeed(new ValidationSeed_1.Seed({ type: 'Text' }, '/path/to/parent/items/1'), new ValidationSeed_1.Seed({
            type: 'GridSequence',
            item: [],
            data: {}
        }, '/path/to/parent'));
        var results = multiChildComponentValidator.validate(seedComponent);
        (0, chai_1.expect)(results.length).to.be.equal(1);
        (0, chai_1.expect)(results[0].path).to.be.equal('/path/to/parent/items/1');
    });
    it('should report if type is multiChild component with live data - Sequence', function () {
        var seedComponent = new ValidationSeed_1.ValidationSeed(new ValidationSeed_1.Seed({ type: 'Text' }, '/path/to/parent/items/1'), new ValidationSeed_1.Seed({
            type: 'Sequence',
            item: [],
            data: {}
        }, '/path/to/parent'));
        var results = multiChildComponentValidator.validate(seedComponent);
        (0, chai_1.expect)(results.length).to.be.equal(1);
        (0, chai_1.expect)(results[0].path).to.be.equal('/path/to/parent/items/1');
    });
    it('should report if type is multiChild component with live data - Pager', function () {
        var seedComponent = new ValidationSeed_1.ValidationSeed(new ValidationSeed_1.Seed({ type: 'Text' }, '/path/to/parent/item/1'), new ValidationSeed_1.Seed({
            type: 'Pager',
            item: [],
            data: {}
        }, '/path/to/parent'));
        var results = multiChildComponentValidator.validate(seedComponent);
        (0, chai_1.expect)(results.length).to.be.equal(1);
        (0, chai_1.expect)(results[0].path).to.be.equal('/path/to/parent/item/1');
    });
});
//# sourceMappingURL=MultiChildComponentValidator.spec.js.map